From c9059b8a3375ab5c7aa0924018f6b10d592bc8af Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=E5=88=98=E7=BE=A4?= <517067180@qq.com>
Date: Thu, 28 Feb 2019 11:02:33 +0800
Subject: [PATCH 2/2] tools: introduce free_conf() as an alias of
 free_wgdevice()

Improve the coding style of IPC APIs for WireGuard tools.

Signed-off-by: Liu Qun <517067180@qq.com>
---
 src/tools/ipc.c      | 11 ++++++++---
 src/tools/ipc.h      | 23 +++++++++++++++++++++++
 src/tools/show.c     |  6 +++---
 src/tools/showconf.c |  2 +-
 4 files changed, 35 insertions(+), 7 deletions(-)

diff --git a/src/tools/ipc.c b/src/tools/ipc.c
index 528a780..c4f1ae0 100644
--- a/src/tools/ipc.c
+++ b/src/tools/ipc.c
@@ -459,7 +459,7 @@ static int userspace_fetch_conf(struct wgdevice **out, const char *interface)
 	ret = -EPROTO;
 err:
 	free(key);
-	free_wgdevice(conf);
+	free_conf(conf);
 	*out = NULL;
 	fclose(f);
 	errno = -ret;
@@ -932,7 +932,7 @@ try_again:
 
 	nlg = mnlg_socket_open(WG_GENL_NAME, WG_GENL_VERSION);
 	if (!nlg) {
-		free_wgdevice(*conf);
+		free_conf(*conf);
 		*conf = NULL;
 		return -errno;
 	}
@@ -955,7 +955,7 @@ out:
 		mnlg_socket_close(nlg);
 	}
 	if (ret) {
-		free_wgdevice(*conf);
+		free_conf(*conf);
 		if (ret == -EINTR) {
 			goto try_again;
 		}
@@ -1018,3 +1018,8 @@ int ipc_set_device(const struct wgdevice *newconf)
 	return userspace_set_device(newconf);
 #endif
 }
+
+void free_conf(struct wgdevice *conf)
+{
+	free_wgdevice(conf);
+}
diff --git a/src/tools/ipc.h b/src/tools/ipc.h
index b9923d3..d73e6d2 100644
--- a/src/tools/ipc.h
+++ b/src/tools/ipc.h
@@ -11,7 +11,30 @@
 struct wgdevice;
 
 int ipc_set_device(const struct wgdevice *conf);
+
+/**
+ * Fetch wireguard device configuration
+ *
+ * Fetch wireguard device configuration from kernel through Netlink socket (or through
+ * different IPC methods from the userspace daemon process)
+ *
+ * @param interface - the interface name
+ * @param conf - the output configuration pointer pointing to an allocated memory
+ *               block which should be freed later by free_conf()
+ * @return 0 on success, negetive on errors. This func should never return positive integer.
+ * @see free_conf()
+ */
 int ipc_fetch_conf(struct wgdevice **conf, const char *interface);
+
+/**
+ * Free the memory block allocated by ipc_fetch_conf()
+ *
+ * free_conf() is an alias of free_wgdevice()
+ * @param conf - the pointer that pointing to allocated memory block
+ * @see ipc_fetch_conf()
+ */
+void free_conf(struct wgdevice *conf);
+
 char *ipc_list_devices(void);
 
 #endif
diff --git a/src/tools/show.c b/src/tools/show.c
index fc63d3c..747f409 100644
--- a/src/tools/show.c
+++ b/src/tools/show.c
@@ -407,7 +407,7 @@ int show_main(int argc, char *argv[])
 			if (argc == 3) {
 				if (!ugly_print(conf, argv[2], true)) {
 					ret = 1;
-					free_wgdevice(conf);
+					free_conf(conf);
 					break;
 				}
 			} else {
@@ -416,7 +416,7 @@ int show_main(int argc, char *argv[])
 					printf("\n");
 				}
 			}
-			free_wgdevice(conf);
+			free_conf(conf);
 			ret = 0;
 		}
 		free(interfaces);
@@ -453,7 +453,7 @@ int show_main(int argc, char *argv[])
 		} else {
 			pretty_print(conf);
 		}
-		free_wgdevice(conf);
+		free_conf(conf);
 	}
 	return ret;
 }
diff --git a/src/tools/showconf.c b/src/tools/showconf.c
index e7b0b5e..f410e9f 100644
--- a/src/tools/showconf.c
+++ b/src/tools/showconf.c
@@ -110,6 +110,6 @@ int showconf_main(int argc, char *argv[])
 	ret = 0;
 
 cleanup:
-	free_wgdevice(conf);
+	free_conf(conf);
 	return ret;
 }
-- 
2.20.1.windows.1

